@@ -61,6 +61,9 @@ class _HydraulicLongitudinalStation(_Model):
     cross_section: List[_HydraulicCrossSectionStation] = Field(
         ..., min_items=3, description="List of points defining the channel bottom"
     )
+    initial_level: Optional[float] = Field(
+        None, description="Initial level for simulation"
+    )
 
     @validator("cross_section")
     def check_cross_section_stations(cls, v: Any) -> Any:
@@ -102,6 +105,9 @@ class _HydraulicRouting(_Model):
     roughness_model: ChannelRoughnessModel = Field(
         ChannelRoughnessModel.CHEZY, description="Friction loss approximation method"
     )
+    initial_flow: Optional[float] = Field(
+        None, description="Initial volumetric flow rate for simulation in m3/s"
+    )
 
     @validator("stations")
     def stations_sorted(cls, v: Any) -> Any:
@@ -188,6 +194,9 @@ class FlowControlledStructure(_Link):
     element_class: str = Field("FlowControlledStructure", const=True)
     min_flow: float = Field(..., description="Minimum volumetric flow rate in m^3/s")
     max_flow: float = Field(..., description="Maximum volumetric flow rate in m^3/s")
+    initial_flow: Optional[float] = Field(
+        None, description="Initial volumetric flow rate for simulation in m^3/s"
+    )
 
     @validator("max_flow")
     def min_flow_le_max_flow(cls, v: Any, values: Dict[str, Any]) -> Any:
@@ -213,6 +222,7 @@ class _PumpTurbineEfficiencyPoint(_Model):
     flow: float = Field(..., ge=0.0)
     head: float = Field(..., ge=0.0)
     efficiency: float = Field(..., gt=0.0, le=1.0)
+    standard_deviation: Optional[float] = Field(5e-3, ge=0.0, le=1.0)
 
 
 class _PumpTurbineHeadTWCorrection(_Model):
@@ -239,6 +249,9 @@ class _PumpTurbine(_Link):
     length: Optional[float] = Field(None, gt=0.0, description="Length of flow path")
     min_flow: float = Field(..., description="Minimum volumetric flow rate in m^3/s")
     max_flow: float = Field(..., description="Maximum volumetric flow rate in m^3/s")
+    initial_flow: Optional[float] = Field(
+        None, description="Initial volumetric flow rate for simulation in m^3/s"
+    )
     min_head: Optional[float] = Field(None, ge=0.0, description="Minimum head in m")
     max_head: Optional[float] = Field(None, ge=0.0, description="Maximum head in m")
     min_power: float = Field(..., description="Minimum power in W")
@@ -342,6 +355,9 @@ class Weir(_FlowRelation):
     element_class: str = Field("Weir", const=True)
     min_crest_level: float = Field(..., description="Minimum crest level")
     max_crest_level: float = Field(..., description="Maximum crest level")
+    initial_crest_level: Optional[float] = Field(
+        None, description="Initial crest level value for simulation"
+    )
     crest_width: float = Field(..., gt=0.0)
 
     @validator("max_crest_level")
@@ -356,6 +372,9 @@ class _TopDownOrifice(_FlowRelation):
     bottom_level: float = Field(..., description="Bottom level")
     min_top_level: float = Field(..., description="Minimum top level")
     max_top_level: float = Field(..., description="Maximum top level")
+    initial_top_level: Optional[float] = Field(
+        None, description="Initial top level value for simulation"
+    )
     reference_width: float = Field(..., gt=0.0)
 
 
@@ -372,3 +391,6 @@ class Drain(_FlowRelation):
     level: float = Field(..., description="Level at which drain is installed")
     min_area: float = Field(..., ge=0.0, description="Minimum aperture area")
     max_area: float = Field(..., gt=0.0, description="Maximum aperture area")
+    initial_area: Optional[float] = Field(
+        None, description="Initial area value for simulation"
+    )
