@@ -32,6 +32,7 @@ elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -67,6 +68,7 @@ elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -83,6 +85,14 @@ elements = [
         "length": 100.0,
         "display_name": "channel",
         "element_class": "Channel",
+        "user_metadata": {
+            "ArbitraryKey": "1",
+            "ArbitraryKey2": 1.0,
+            "ArbitraryKey3": 1,
+            "ArbitraryKey4": True,
+            "ArbitraryKey5": 1.1,
+        },
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -96,6 +106,7 @@ elements = [
         "length": 100.0,
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -106,6 +117,7 @@ elements = [
         "transit_time": 10.0,
         "display_name": "delay",
         "element_class": "Delay",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -116,6 +128,7 @@ elements = [
         "max_flow": 1.0,
         "display_name": "flow_controlled_structure",
         "element_class": "FlowControlledStructure",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -129,6 +142,7 @@ elements = [
         "max_area": 10.0,
         "display_name": "drain",
         "element_class": "Drain",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -142,6 +156,7 @@ elements = [
         "check_valve": False,
         "display_name": "pipe",
         "element_class": "Pipe",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -158,6 +173,7 @@ elements = [
         "max_power": 1.0,
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -174,6 +190,7 @@ elements = [
         "max_power": 1.0,
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -192,6 +209,7 @@ elements = [
         "max_head": 1.0,
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -210,6 +228,7 @@ elements = [
         "max_head": 1.0,
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -222,6 +241,7 @@ elements = [
         "setting": 0.0,
         "display_name": "valve",
         "element_class": "Valve",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -235,6 +255,7 @@ elements = [
         "crest_width": 10.0,
         "display_name": "weir",
         "element_class": "Weir",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -243,6 +264,7 @@ elements = [
         "display_name": "flow_boundary",
         "schematic_location": {"x": 0.0, "y": 0.0, "z": 0.0},
         "element_class": "FlowBoundary",
+        "collection": "nodes",
         "domain": "water",
     },
     {
@@ -251,6 +273,7 @@ elements = [
         "display_name": "junction",
         "schematic_location": {"x": 0.0, "y": 1.0, "z": 0.0},
         "element_class": "Junction",
+        "collection": "nodes",
         "domain": "water",
     },
     {
@@ -259,6 +282,7 @@ elements = [
         "display_name": "level_boundary",
         "schematic_location": {"x": 1.0, "y": 0.0, "z": 0.0},
         "element_class": "LevelBoundary",
+        "collection": "nodes",
         "domain": "water",
     },
     {
@@ -271,6 +295,7 @@ elements = [
         "display_name": "storage",
         "schematic_location": {"x": 1.0, "y": 1.0, "z": 0.0},
         "element_class": "Storage",
+        "collection": "nodes",
         "domain": "water",
     },
 ]
@@ -297,6 +322,7 @@ bad_elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -327,6 +353,7 @@ bad_elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -349,6 +376,7 @@ bad_elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -362,6 +390,7 @@ bad_elements = [
         "length": 100.0,
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -375,6 +404,7 @@ bad_elements = [
         "length": 100.0,
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -391,6 +421,7 @@ bad_elements = [
         "length": 100.0,
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -426,6 +457,7 @@ bad_elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -461,6 +493,7 @@ bad_elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -477,6 +510,7 @@ bad_elements = [
         "length": 100.0,
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -499,6 +533,7 @@ bad_elements = [
         },
         "display_name": "channel",
         "element_class": "Channel",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -512,6 +547,7 @@ bad_elements = [
         "max_power": 1.0,
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -525,6 +561,7 @@ bad_elements = [
         "max_power": 1.0,
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -537,6 +574,7 @@ bad_elements = [
         "max_power": 1.0,
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -549,7 +587,9 @@ bad_elements = [
         "max_power": 1.0,
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
+        "collection": "links",
     },
     {
         "uid": "pump3",
@@ -561,6 +601,7 @@ bad_elements = [
         "max_power": 1.0,
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -573,6 +614,7 @@ bad_elements = [
         "max_power": 1.0,
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -581,6 +623,7 @@ bad_elements = [
         "target_uid": "storage",
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -589,6 +632,7 @@ bad_elements = [
         "target_uid": "storage",
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -603,6 +647,7 @@ bad_elements = [
         "max_head": 1.0,
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -617,6 +662,7 @@ bad_elements = [
         "max_head": 1.0,
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -631,6 +677,7 @@ bad_elements = [
         "max_speed": 1.0,
         "display_name": "pump",
         "element_class": "Pump",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -645,6 +692,7 @@ bad_elements = [
         "max_speed": 1.0,
         "display_name": "turbine",
         "element_class": "Turbine",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -655,6 +703,7 @@ bad_elements = [
         "max_flow": math.inf,
         "display_name": "flow_controlled_structure",
         "element_class": "FlowControlledStructure",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -665,6 +714,7 @@ bad_elements = [
         "max_flow": 0.0,
         "display_name": "flow_controlled_structure",
         "element_class": "FlowControlledStructure",
+        "collection": "links",
         "domain": "water",
     },
     {
@@ -675,6 +725,7 @@ bad_elements = [
         "max_flow": 1.0,
         "display_name": "flow_controlled_structure",
         "element_class": "FlowControlledStructure",
+        "collection": "links",
         "domain": "water",
     },
     {
